import {app, BrowserWindow} from "electron";
import * as url from "url";
import * as path from "path";

let mainWindow:BrowserWindow | null;

function createWindow() {
    // メインウィンドウを作る
    mainWindow = new BrowserWindow({
        width:800,
        height:600
    });

    // メインウィンドウにindex.htmlを読み込む
    mainWindow.loadURL(url.format({
        pathname:path.join(__dirname, "index.html"),
        protocol:"file:",
        slashes:true
    }));

    // ウィンドウが閉じられたときの処理を追加
    mainWindow.on("closed", ()=>{
        mainWindow = null;
    })
}

// ウィンドウの作成準備ができたときの処理を追加
app.on("ready", createWindow);

// すべてのウィンドウが閉じれたときに呼ばれる。
app.on("window-all-closed", ()=>{
    // macOS以外は終了
    // macOSの場合は通常すべてのウィンドウを閉じても
    // アプリは終了しないのでmacOSではapp.quit()を呼ばない。
    if(process.platform !== "darwin") {
        app.quit();
    }
});

// アプリがアクティブになるときの処理を追加
app.on("activate", ()=>{
    if(mainWindow === null) {
        createWindow();
    }
});